#
# spec file for package OpenIPMI
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           OpenIPMI
BuildRequires:  gd-devel gdbm-devel glib2-devel libjpeg-devel libpng-devel ncurses-devel net-snmp-devel openssl-devel pkg-config popt-devel python-devel python-tk pyxml swig tcl-devel tix
License:        GPL v2 or later
Group:          System/Monitoring
Version:        2.0.14
Release:        2.7.12
Source0:        %{name}-%{version}.tar.bz2
Source1:        sysconfig.ipmi
Source2:        openipmi.initscript
Patch0:         OpenIPMI-prefer_perl_vendor.patch
Patch1:         OpenIPMI-remove_compile_warning.patch
Patch2:         new-names-for-new-variables
Patch3:         OpenIPMI-libtool.patch
Patch4:         OpenIPMI-popt.patch
Patch5:         OpenIPMI-return.patch
Url:            http://openipmi.sourceforge.net
Provides:       ipmilan ipmicmd ipmi_ui openipmigui
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        OpenIPMI
PreReq:         %install_info_prereq %insserv_prereq %fillup_prereq  
# Perl is sometimes installed in /usr/lib, not /usr/lib64 on 64-bit platforms.
# %define perl_libdir %{_exec_prefix}/lib

%description
OpenIPMI is an effort to create a full-function IPMI system to allow
full access to all IPMI information on a server and to abstract it to a
level that makes it easy to use.

OpenIPMI consists of two main parts: a device driver that is included
in the Linux kernel and a user-level library that provides a
higher-level abstraction of IPMI and generic services that can be used
on any operation system. This package contains the user-level library
part. This OpenIPMI library also includes the ipmicmd program, a small
program that lets you inject and receive messages.



Authors:
--------
    Corey Minyard <cminyard@users.sourceforge.net>
    Rocky Craig <coloroco@users.sourceforge.net>

%package devel
License:        GPL v2 or later
Summary:        OpenIPMI  - Development libraries
Group:          Development/Libraries/Other
Provides:       libIPMIlanserv libOpenIPMI libOpenIPMIui
Requires:       OpenIPMI = %{version} openssl-devel ncurses-devel
AutoReqProv:    on

%description devel
These libraries are needed to get full access to the OpenIPMI
functions.



Authors:
--------
    Corey Minyard <cminyard@users.sourceforge.net>
    Rocky Craig <coloroco@users.sourceforge.net>

%prep
%setup -n %{name}-%{version}
%patch0 -p1
%patch1 -p0
%patch2 -p1
%patch3
%patch4
%patch5

%build
autoreconf --install --force
CFLAGS="$RPM_OPT_FLAGS" \
  ./configure --prefix=%{_prefix} \
          --libdir=%{_libdir} \
          --mandir=%{_mandir} \
          --infodir=%{_infodir} \
          --with-openssl=yes \
          --with-tcl=yes \
          --with-tcllibs=-ltcl8.4
make

%install
make DESTDIR=$RPM_BUILD_ROOT install
install -d $RPM_BUILD_ROOT/var/adm/fillup-templates
install -d $RPM_BUILD_ROOT/etc/init.d
install -d $RPM_BUILD_ROOT/sbin
install -m 644 %{S:1} $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 755 %{S:2} $RPM_BUILD_ROOT/etc/init.d/ipmi
ln -sf ../etc/init.d/ipmi $RPM_BUILD_ROOT/sbin/rcipmi

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && [ -d $RPM_BUILD_ROOT ] && rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig
%{fillup_and_insserv -n ipmi ipmi}

%postun
/sbin/ldconfig
%restart_on_update ipmi
%insserv_cleanup

%post devel
%install_info --info-dir=%_infodir %_infodir/%name.info.gz

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
%doc CONFIGURING_FOR_LAN COPYING COPYING.BSD COPYING.LIB FAQ INSTALL 
%doc README README.Force README.MotorolaMXP
/var/adm/fillup-templates/sysconfig.ipmi
/etc/init.d/ipmi
/sbin/rcipmi
%{_libdir}/libOpenIPMI*.so.*
###### perl files ######
%dir %{perl_vendorarch}/auto/OpenIPMI
%{perl_vendorarch}/auto/OpenIPMI/OpenIPMI.so
%{perl_vendorarch}/OpenIPMI.pm
%doc swig/OpenIPMI.i swig/perl/sample swig/perl/ipmi_powerctl
###### python files ######
%{_libdir}/python*/site-packages/*OpenIPMI.*
%doc swig/OpenIPMI.i
###### gui files ######
%dir %{_libdir}/python*/site-packages/openipmigui
%{_libdir}/python*/site-packages/openipmigui/*
%{_bindir}/openipmigui
###### ui files ######
%{_bindir}/ipmi_ui
%{_bindir}/ipmicmd
%{_bindir}/openipmicmd
%{_bindir}/ipmish
%{_bindir}/openipmish
%{_bindir}/solterm
%{_bindir}/rmcp_ping
%doc %{_mandir}/man1/ipmi_ui.1*
%doc %{_mandir}/man1/openipmicmd.1*
%doc %{_mandir}/man1/openipmish.1*
%doc %{_mandir}/man1/openipmigui.1*
%doc %{_mandir}/man1/solterm.1*
%doc %{_mandir}/man1/rmcp_ping.1*
%doc %{_mandir}/man7/ipmi_cmdlang.7*
%doc %{_mandir}/man7/openipmi_conparms.7*
###### lanserv files #####
%{_bindir}/ipmilan
%{_libdir}/libIPMIlanserv.so.*
%doc %{_mandir}/man8/ipmilan.8*

%files devel
%defattr(644,root,root,755)
%{_prefix}/include/*
%{_prefix}/%{_lib}/*.a
%{_prefix}/%{_lib}/*.la
%{_prefix}/%{_lib}/*.so
%{_prefix}/%{_lib}/pkgconfig/*.pc
%doc doc/IPMI.pdf
###################################################

%changelog
* Fri Jan 14 2011 duwe@suse.de
- Allow the timeout for /dev/ipmi0 appearance to be modified
  by a sysconfig variable (bnc#437684).
* Fri May 29 2009 kukuk@suse.de
- Backport for SLE10 SP3 [FATE#306228]
* Thu Sep 11 2008 kukuk@suse.de
- Update to 2.0.14 [fate#304439]
- fix at least the worst bugs in init script
* Tue May  6 2008 coolo@suse.de
- return in non-void functions
* Tue Apr 15 2008 schwab@suse.de
- Fix popt configure check.
* Mon Apr 14 2008 schwab@suse.de
- Work around misuse of libtool.
* Sun Apr  6 2008 coolo@suse.de
- build with latest tcl, reduce build requires
* Mon Mar  3 2008 duwe@suse.de                                                               
- make the sample program dump_sensors exit cleanly.
* Wed Jan 16 2008 duwe@suse.de
- Update to 2.0.13
  + better sensors support
  + numerous bug fixes, including #310247
- fixed bug#156215
* Fri Apr 20 2007 aj@suse.de
- Package does not need latex for normal building, remove build
  dependency.
* Mon Mar 26 2007 rguenther@suse.de
- package .la and .so file in OpenIPMI-devel package only
- add gdbm-devel BuildRequires
* Mon Feb  5 2007 duwe@suse.de
- fix not-really-shadowing variable with questionable behaviour
  (reported in Bug #232439)
* Wed Dec 20 2006 coyli@suse.de
- fix misconfigured destination library directory for perl
  and python code.
- add openssl-devel and ncurse-devel in Build Requires of
  OpenIPMI-devel.
* Tue Nov  7 2006 coyli@suse.de
- fix deadlock in openipmigui (BUG #206661)
- get openssl linked in
- remove compiling warning in source code
- modify licnese from GPL to LGPL
- fix an out of range looping bug, which chould cause crash
  to programs linked with OpenIPMI library
* Thu Sep 21 2006 duwe@suse.de
- satisfy FATE #300745
* Thu Sep 14 2006 duwe@suse.de
- Update to 2.0.7 (thanks, coly)
  + new front-ends, some graphical ("openipmigui")
  + various bugfixes
  + new FRU interface
  + tcl bindings added
  site_perl spared thanks to Rudi.
* Mon May 29 2006 kukuk@suse.de
- ipmi init script: Replace /sbin/udev with /sbin/udevd [#174010]
* Fri Mar  3 2006 duwe@suse.de
- update to 1.4.26
  - various small bug and memory leak fixes
  - fix local operation on ATCA
  - add support for multiple IPMB channels with different IPMB
    addresses
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 duwe@suse.de
- Add %%insserv_prereq and %%fillup_prereq fixing Bug #140314
* Mon Dec 19 2005 ro@suse.de
- fixed filelist
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Wed Oct 26 2005 duwe@suse.de
- add patches by matt to sync with upstream (#128770)
* Mon Oct 10 2005 duwe@suse.de
- rc script name change openipmi->ipmi (Bug #120227)
- default start in runlevels 2 3 5 (Bug #121651)
* Thu Sep 22 2005 duwe@suse.de
- Update to version 1.4.19 (#117699)
- add initscripts (#117103)
* Mon Jun  6 2005 mrueckert@suse.de
- Update to version 1.4.16
* Tue May 10 2005 meissner@suse.de
- fixed potential 2 byte overflow due to bug in strncpy().
* Sat Mar 26 2005 nashif@suse.de
- Fixed license in include file (#74351)
* Fri Feb 18 2005 nashif@suse.de
- Update to 1.3.17
- Split package
* Sat Jan  8 2005 nashif@suse.de
- Fixed installation of info files
* Tue Jan  4 2005 nashif@suse.de
- Update to version 1.3.16
* Thu Oct 28 2004 nashif@suse.de
- Updated to version 1.3.11
* Tue Aug 10 2004 nashif@suse.de
- Updated to version 1.3.9
* Tue Jun  8 2004 nashif@suse.de
- Updated to version 1.3.8
* Thu May  6 2004 nashif@suse.de
- Added a way to get the number of entries and free
  bytes in the SEL.
* Fri Apr 30 2004 nashif@suse.de
- Fixes by author:
  * lib/sel.c: Fixed a bug in the sel get where the info allocated
  can go away before the operation returns, but the info is used
  after the operation returns.
  * lib/sensor.c: Fix the hysteresis setting to send a message that
  is the right size.
* Wed Apr 28 2004 nashif@suse.de
- Updated to 1.3.6 (as per bug #38602)
* Mon Mar 22 2004 nashif@suse.de
- Enabled sources again
- files with legal issues have been removed upstream
* Mon Mar 22 2004 nashif@suse.de
- Update to release 1.2.21
* Fri Feb 27 2004 tsieden@suse.de
- update to release 1.2.7
- replaced test_md2.c with a dummy, switched to a nosrc.rpm
  to avoid legal problems
* Mon Oct 27 2003 kukuk@suse.de
- Don't link static libraries in shared one without -fPIC compiled
- Fix building on lib64 architectures
* Thu Oct 23 2003 tsieden@suse.de
- branched -devel package
* Fri Oct 17 2003 tsieden@suse.de
- initial release 1.1.4
